Renderer

Struct Renderer 

pub struct Renderer { /* private fields */ }
GPU renderer that draws a RenderFrame using six shader pipelines.

Implementations

Source

impl Renderer

pub fn new(device: Device, queue: Queue, surface_format: TextureFormat) -> Self

Create a new renderer from an existing wgpu device and queue.

pub fn upload_atlas(&mut self, width: u32, height: u32, pixels: &[u8])

Upload atlas texture data from the text backend.

pub fn render( &mut self, frame: &RenderFrame, view: &TextureView, scale_factor: f32, viewport_width: u32, viewport_height: u32, clear_color: [f32; 4], )

Render a frame to the given surface texture view.

pub fn device(&self) -> &Device

pub fn queue(&self) -> &Queue

pub fn register_image( &mut self, name: &str, width: u32, height: u32, pixels: &[u8], )

Register an image for rendering by name.

pub fn remove_image(&mut self, name: &str)

Remove a registered image.